@@ -9,13 +9,14 @@ import os
 import sys
 import inspect
 
-__version__ = '0.3.6'
+__version__ = '0.3.7'
 
 
 #{ Initialization
 def _init_externals():
     """Initialize external projects by putting them into the path"""
-    sys.path.append(os.path.join(os.path.dirname(__file__), 'ext', 'gitdb'))
+    if __version__ == '0.3.7':
+        sys.path.insert(0, os.path.join(os.path.dirname(__file__), 'ext', 'gitdb'))
 
     try:
         import gitdb
