@@ -15,7 +15,9 @@ import io
 from git import Repo, Remote, GitCommandError, Git
 from git.compat import string_types
 
-GIT_REPO = os.path.dirname(os.path.dirname(os.path.dirname(os.path.dirname(__file__))))
+osp = os.path.dirname
+
+GIT_REPO = os.environ.get("GIT_PYTHON_TEST_GIT_REPO_BASE", osp(osp(osp(osp(__file__)))))
 
 __all__ = (
     'fixture_path', 'fixture', 'absolute_project_path', 'StringProcessAdapter',
@@ -26,7 +28,7 @@ __all__ = (
 
 
 def fixture_path(name):
-    test_dir = os.path.dirname(os.path.dirname(__file__))
+    test_dir = osp(osp(__file__))
     return os.path.join(test_dir, "fixtures", name)
 
 
@@ -35,7 +37,7 @@ def fixture(name):
 
 
 def absolute_project_path():
-    return os.path.abspath(os.path.join(os.path.dirname(__file__), "..", ".."))
+    return os.path.abspath(os.path.join(osp(__file__), "..", ".."))
 
 #} END routines
 
@@ -195,7 +197,7 @@ def with_rw_and_rw_remote_repo(working_tree_ref):
 
             d_remote.config_writer.set('url', remote_repo_url)
 
-            temp_dir = os.path.dirname(_mktemp())
+            temp_dir = osp(_mktemp())
             # On windows, this will fail ... we deal with failures anyway and default to telling the user to do it
             try:
                 gd = Git().daemon(temp_dir, enable='receive-pack', as_process=True)
@@ -230,7 +232,13 @@ def with_rw_and_rw_remote_repo(working_tree_ref):
             prev_cwd = os.getcwd()
             os.chdir(rw_repo.working_dir)
             try:
-                return func(self, rw_repo, rw_remote_repo)
+                try:
+                    return func(self, rw_repo, rw_remote_repo)
+                except:
+                    print("Keeping repos after failure: repo_dir = %s, remote_repo_dir = %s"
+                          % (repo_dir, remote_repo_dir), file=sys.stderr)
+                    repo_dir = remote_repo_dir = None
+                    raise
             finally:
                 # gd.proc.kill() ... no idea why that doesn't work
                 if gd is not None:
@@ -239,8 +247,10 @@ def with_rw_and_rw_remote_repo(working_tree_ref):
                 os.chdir(prev_cwd)
                 rw_repo.git.clear_cache()
                 rw_remote_repo.git.clear_cache()
-                shutil.rmtree(repo_dir, onerror=_rmtree_onerror)
-                shutil.rmtree(remote_repo_dir, onerror=_rmtree_onerror)
+                if repo_dir:
+                    shutil.rmtree(repo_dir, onerror=_rmtree_onerror)
+                if remote_repo_dir:
+                    shutil.rmtree(remote_repo_dir, onerror=_rmtree_onerror)
 
                 if gd is not None:
                     gd.proc.wait()
