@@ -313,8 +313,7 @@ class TestRemote(TestBase):
         self._do_test_push_result(res, remote)
 
         # invalid refspec
-        res = remote.push("hellothere")
-        assert len(res) == 0
+        self.failUnlessRaises(GitCommandError, remote.push, "hellothere")
 
         # push new tags
         progress = TestRemoteProgress()
@@ -445,6 +444,24 @@ class TestRemote(TestBase):
         origin = rw_repo.remote('origin')
         assert origin == rw_repo.remotes.origin
 
+        # Verify we can handle prunes when fetching
+        # stderr lines look like this:  x [deleted]         (none)     -> origin/experiment-2012
+        # These should just be skipped
+        # If we don't have a manual checkout, we can't actually assume there are any non-master branches
+        remote_repo.create_head("myone_for_deletion")
+        # Get the branch - to be pruned later
+        origin.fetch()
+
+        num_deleted = False
+        for branch in remote_repo.heads:
+            if branch.name != 'master':
+                branch.delete(remote_repo, branch, force=True)
+                num_deleted += 1
+            # end
+        # end for each branch
+        assert num_deleted > 0
+        assert len(rw_repo.remotes.origin.fetch(prune=True)) == 1, "deleted everything but master"
+
     @with_rw_repo('HEAD', bare=True)
     def test_creation_and_removal(self, bare_rw_repo):
         new_name = "test_new_one"
@@ -468,6 +485,9 @@ class TestRemote(TestBase):
             # END if deleted remote matches existing remote's name
         # END for each remote
 
+        # Issue #262 - the next call would fail if bug wasn't fixed
+        bare_rw_repo.create_remote('bogus', '/bogus/path', mirror='push')
+
     def test_fetch_info(self):
         # assure we can handle remote-tracking branches
         fetch_info_line_fmt = "c437ee5deb8d00cf02f03720693e4c802e99f390	not-for-merge	%s '0.3' of "
