@@ -27,7 +27,8 @@ from git import (
     Submodule,
     GitCmdObjectDB,
     Remote,
-    BadName
+    BadName,
+    GitCommandError
 )
 from git.repo.fun import touch
 from git.util import join_path_native
@@ -163,6 +164,7 @@ class TestRepo(TestBase):
                 r = Repo.init(path=path, bare=True)
                 assert isinstance(r, Repo)
                 assert r.bare is True
+                assert not r.has_separate_working_tree()
                 assert os.path.isdir(r.git_dir)
 
                 self._assert_empty_repo(r)
@@ -199,6 +201,7 @@ class TestRepo(TestBase):
             os.chdir(git_dir_rela)
             r = Repo.init(bare=False)
             assert r.bare is False
+            assert not r.has_separate_working_tree()
 
             self._assert_empty_repo(r)
         finally:
@@ -265,7 +268,7 @@ class TestRepo(TestBase):
     def test_archive(self):
         tmpfile = tempfile.mktemp(suffix='archive-test')
         stream = open(tmpfile, 'wb')
-        self.rorepo.archive(stream, '0.1.5')
+        self.rorepo.archive(stream, '0.1.6', path='doc')
         assert stream.tell()
         stream.close()
         os.remove(tmpfile)
@@ -552,7 +555,7 @@ class TestRepo(TestBase):
         # start from reference
         num_resolved = 0
 
-        for ref in Reference.iter_items(self.rorepo):
+        for ref_no, ref in enumerate(Reference.iter_items(self.rorepo)):
             path_tokens = ref.path.split("/")
             for pt in range(len(path_tokens)):
                 path_section = '/'.join(path_tokens[-(pt + 1):])
@@ -566,6 +569,8 @@ class TestRepo(TestBase):
                     pass
                 # END exception handling
             # END for each token
+            if ref_no == 3 - 1:
+                break
         # END for each reference
         assert num_resolved
 
@@ -588,8 +593,8 @@ class TestRepo(TestBase):
         commit = rev_parse(first_rev)
         assert len(commit.parents) == 0
         assert commit.hexsha == first_rev
-        self.failUnlessRaises(BadObject, rev_parse, first_rev + "~")
-        self.failUnlessRaises(BadObject, rev_parse, first_rev + "^")
+        self.failUnlessRaises(BadName, rev_parse, first_rev + "~")
+        self.failUnlessRaises(BadName, rev_parse, first_rev + "^")
 
         # short SHA1
         commit2 = rev_parse(first_rev[:20])
@@ -737,3 +742,24 @@ class TestRepo(TestBase):
         # Now a branch should be creatable
         nb = r.create_head('foo')
         assert nb.is_valid()
+
+    def test_merge_base(self):
+        repo = self.rorepo
+        c1 = 'f6aa8d1'
+        c2 = repo.commit('d46e3fe')
+        c3 = '763ef75'
+        self.failUnlessRaises(ValueError, repo.merge_base)
+        self.failUnlessRaises(ValueError, repo.merge_base, 'foo')
+
+        # two commit merge-base
+        res = repo.merge_base(c1, c2)
+        assert isinstance(res, list) and len(res) == 1 and isinstance(res[0], Commit)
+        assert res[0].hexsha.startswith('3936084')
+
+        for kw in ('a', 'all'):
+            res = repo.merge_base(c1, c2, c3, **{kw: True})
+            assert isinstance(res, list) and len(res) == 1
+        # end for eaech keyword signalling all merge-bases to be returned
+
+        # Test for no merge base - can't do as we have
+        self.failUnlessRaises(GitCommandError, repo.merge_base, c1, 'ffffff')
